@@ -1,6 +1,6 @@
 package MARC::Moose::Formater::UnimarcToMarc21;
 {
-  $MARC::Moose::Formater::UnimarcToMarc21::VERSION = '0.030';
+  $MARC::Moose::Formater::UnimarcToMarc21::VERSION = '1.0.0';
 }
 # ABSTRACT: Convert biblio record from UNIMARC to MARC21
 use Moose;
@@ -249,7 +249,8 @@ override 'format' => sub {
 
     # 100 => 008
     if ( my $field = $unimarc->field('100') ) {
-        if ( my $code100 = $field->subfield('a') ) {
+        my $code100 = $field->subfield('a');
+        if ( $code100 && length($code100) > 20 ) {
             # Date entered on file
             substr $code008, 0, 6, substr($code100, 2, 6);
 
@@ -869,7 +870,8 @@ override 'format' => sub {
                     $value =~ s/\x{0088}//g;
                     $value =~ s/\x{0089}//g;
                 }
-                $letter = $letter eq '3' ? 'w' :
+                $letter = $letter eq '1' ? 'a' :
+                          $letter eq '3' ? 'w' :
                           $letter eq 'v' ? 'g' :
                           $letter eq 'y' ? 'z' : $letter;
                 push @sf, [ $letter => $value ];
@@ -1093,7 +1095,7 @@ MARC::Moose::Formater::UnimarcToMarc21 - Convert biblio record from UNIMARC to M
 
 =head1 VERSION
 
-version 0.030
+version 1.0.0
 
 =head1 SYNOPSYS
 
